# coding: utf-8
"""
選択している面のうち，uv座標が近い点の座標を合わせます（uv座標の頂点スナップ）
active_shape()に対して実行します．
"""
__author__ = "CASPAR003 <caspar003@caspar003.info>"
__date__ = "2014-09-15/2014-09-15"
__version__ = "1.0"

def main(shape):
    """
    動作概要
    ・shapeから選択されている2面を選ぶ（active_faceの0と1を読む）
    ・2面を調べuv座標が近い頂点があったら原点に近い側にスナップする
    """
    import numpy as np
    d = 0.01    # スナップ距離
    
    if (shape.type != 7): return
    
    active_face_ids = shape.active_face_indices
    if (len(active_face_ids) < 2): return
    
    vertex_nums = []
    vertex_nums.append(shape.face(active_face_ids[0]).number_of_vertices)
    vertex_nums.append(shape.face(active_face_ids[1]).number_of_vertices)
    
    for vi in range(vertex_nums[0]):
        uvi = np.array(shape.face(active_face_ids[0]).get_face_uv(0, vi))
        for vj in range(vertex_nums[1]):
            uvj = np.array(shape.face(active_face_ids[1]).get_face_uv(0, vj))
            
            # uv空間上の2点の距離がdより小さければスナップする
            if (np.linalg.norm(uvj - uvi) < d):
                if (np.linalg.norm(uvi) < np.linalg.norm(uvj)):    # viを基準にスナップ
                    shape.face(active_face_ids[1]).set_face_uv(0, vj, shape.face(active_face_ids[0]).get_face_uv(0, vi))
                else:    # vjを基準にスナップ
                    shape.face(active_face_ids[0]).set_face_uv(0, vi, shape.face(active_face_ids[1]).get_face_uv(0, vj))
    return

if (__name__ == "__main__"):
    shape = xshade.scene().active_shape()
    if (shape is not None):
        main(shape)